pub struct LocalNodeInfo {
pub moniker: String,
pub peer_id: PeerId,
pub listen_addr: Multiaddr,
pub consensus_address: Option<String>,
pub is_validator: bool,
pub persistent_peers_only: bool,
pub subscribed_topics: HashSet<String>,
}Expand description
Local node information
Fields
moniker: Stringpeer_id: PeerIdlisten_addr: Multiaddrconsensus_address: Option<String>This node’s consensus address (if it is configured with validator credentials).
Present if the node has a consensus keypair, even if not currently in the active validator set. This is static configuration determined at startup. Note: In the future full nodes will not have a consensus address, so this will be None.
is_validator: boolWhether this node is currently in the active validator set.
Updated dynamically when validator set changes. A node can have consensus_address = Some(...)
but is_validator = false if it was removed from the validator set or hasn’t joined yet.
persistent_peers_only: boolWhether this node only accepts connections from persistent peers.
subscribed_topics: HashSet<String>Trait Implementations
Sourceimpl Clone for LocalNodeInfo
impl Clone for LocalNodeInfo
Sourcefn clone(&self) -> LocalNodeInfo
fn clone(&self) -> LocalNodeInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LocalNodeInfo
impl Debug for LocalNodeInfo